AFCCA Opinions

Home |  | Court Docket |  | Oral Argument Docket |  | Opinions/Orders |  | Audio File Archive |  | Court News |  | Information |  | Contact Us |

| AFCCA Opinions
About AFCCA Opinions To learn more about AFCCA opinions, please review our AFCCA Opinions fact sheet.
Locating AFCCA Opinions To locate an AFCCA opinion you may:
| View opinions by year: |
| Search for opinions using the AFCCA Opinion Locator.
Sort By: Case Name | Appellant | ACM | Status | Date Decided
Opinions Listed: 184 Total Opinions: 184
Case Name | ACM | Status | Decided
| United States v. Clark | S32201 | Unpublished | 11 Sep 14
| United States v. Kelly | S32183 | Merits | 11 Sep 14
| United States v. Lammens | 38185 (f rev) | Unpublished | 11 Sep 14
| United States v. Reed | 38428 | Unpublished | 11 Sep 14
| United States v. Hudson | S32167 | Unpublished | 09 Sep 14
| United States v. Janssen | 37681 (rem) | Unpublished | 09 Sep 14
| United States v. Newhouse | 38019 (recon 2) | Unpublished | 04 Sep 14
| United States v. Norman | 37945 (recon 2) | Unpublished | 04 Sep 14
| United States v. Wence | S32162 | Unpublished | 04 Sep 14
| United States v. Duran | 38404 | Unpublished | 28 Aug 14
| United States v. Stanton | 38385 | Unpublished | 28 Aug 14
| United States v. Carr | 38025 (recon) | Unpublished | 27 Aug 14
| United States v. Jorell | 38061 (recon) | Published | 27 Aug 14
| United States v. Taylor | S32153 | Unpublished | 27 Aug 14
| United States v. Wilson | 37486 (reh) | Unpublished | 27 Aug 14
| United States v. Gnash | S32067 (recon) | Unpublished | 22 Aug 14
| United States v. Mangasarian | 38427 | Unpublished | 22 Aug 14
| United States v. Boore | 38058 (recon 2) | Unpublished | 21 Aug 14
| United States v. Helpap | S32017 (recon 2) | Unpublished | 21 Aug 14
| United States v. Sutton | S32143 | Unpublished | 21 Aug 14
| United States v. Tompkins | 37627 (recon 2) | Unpublished | 18 Aug 14
| United States v. Matthis | 38312 | Unpublished | 14 Aug 14
| United States v. Nystrom | 38351 | Unpublished | 14 Aug 14
| United States v. Reed | S32207 | Merits | 14 Aug 14
| United States v. Verdjo-Ruiz | 37957 (recon) | Unpublished | 14 Aug 14
| United States v. Brilla | 38418 | Merits | 13 Aug 14
| United States v. Patterson | 38031 (recon 2) | Unpublished | 13 Aug 14
| United States v. Piette | 38101 (recon) | Unpublished | 06 Aug 14
| United States v. Thompson | S31996 (recon) | Unpublished | 06 Aug 14
| United States v. Loveridge | 37872 (recon) | Unpublished | 05 Aug 14
| United States v. Martin | S32035 (recon) | Unpublished | 05 Aug 14
| United States v. Paul | S32025 (rem) | Unpublished | 05 Aug 14
| United States v. Arrington | 37698 (f rev) | Unpublished | 01 Aug 14
| United States v. Eichelberger | 38318 | Unpublished | 01 Aug 14
| United States v. Hall | 38241 (recon) | Published | 01 Aug 14
| United States v. Openshaw | 38049 (recon) | Unpublished | 01 Aug 14
| United States v. Spielman | 38285 (Corrected Copy) | Unpublished | 01 Aug 14
| United States v. Henne | 38334 | Unpublished | 30 Jul 14
| United States v. Legaspi | 38344 | Unpublished | 30 Jul 14
| United States v. Smith | S32152 | Unpublished | 30 Jul 14
| United States v. Thomas | S32163 | Unpublished | 30 Jul 14
| United States v. Coleman | 38287 | Unpublished | 29 Jul 14
| United States v. Broussard | S32187 | Merits | 24 Jul 14
| United States v. Cruz | 38296 | Unpublished | 24 Jul 14
| United States v. Latham | 38107 (recon 2) | Unpublished | 24 Jul 14
| United States v. Watkins | S32114 (recon) | Unpublished | 24 Jul 14
| United States v. Watts | S32146 (f rev) | Unpublished | 24 Jul 14
| United States v. Zolnosky | 38103 (recon) | Unpublished | 24 Jul 14
| United States v. Blair | S32028 (recon) | Unpublished | 22 Jul 14
| United States v. Slagle | 38087 (recon) | Published | 22 Jul 14
| United States v. Webb | 38071 (recon 2) | Unpublished | 22 Jul 14
| United States v. Davis | 38359 (Corrected Copy) | Unpublished | 18 Jul 14
| United States v. Dietz | 38117 (rem) | Unpublished | 17 Jul 14
| United States v. Mann | 38124 (recon) | Unpublished | 17 Jul 14
| United States v. Montoya | 38116 (recon) | Unpublished | 17 Jul 14
| United States v. Pesina | S32196 | Merits | 17 Jul 14
| United States v. Williams | S32195 | Merits | 17 Jul 14
| United States v. Luckado | 37962 (recon) | Unpublished | 15 Jul 14
| United States v. Faul | 38486 | Unpublished | 10 Jul 14
| United States v. Long | S32182 | Merits | 10 Jul 14
| United States v. Scarborough | S32180 | Merits | 10 Jul 14
| United States v. Cooper | 38293 | Unpublished | 09 Jul 14
| United States v. Williams | 38255 | Unpublished | 09 Jul 14
| United States v. Smith | S32175 | Merits | 08 Jul 14
| United States v. LaBella | 37679 (rem) | Unpublished | 02 Jul 14
| United States v. Long | 2014-02 | Article 62 | 02 Jul 14
| United States v. Plant | 38274 | Unpublished | 02 Jul 14
| United States v. Stipes | 38421 | Unpublished | 02 Jul 14
| United States v. Teer | S32136 | Unpublished | 02 Jul 14
| United States v. Cutrer | 38515 | Merits | 01 Jul 14
| United States v. Witt | 36785 (recon) | Published | 30 Jun 14
| United States v. Cron | 38138 | Published | 27 Jun 14
| United States v. Moore | 38435 | Merits | 26 Jun 14
| United States v. Love | S32208 | Merits | 25 Jun 14
| United States v. Chamblee | 38453 | Unpublished | 17 Jun 14
| United States v. Kates | 2014-05 | Order | 17 Jun 14
| United States v. McClelland-Hall | 38258 (recon) | Merits | 17 Jun 14
| United States v. Powers | 2014-07 | Order | 17 Jun 14
| United States v. Roy | 2014-06 | Order | 17 Jun 14
| United States v. Thompson | 37269 | Unpublished | 17 Jun 14
| United States v. Watts | S32146 | Unpublished | 17 Jun 14
| United States v. Klein | 38273 | Unpublished | 16 Jun 14
| United States v. MacDonald | 38491 | Merits | 16 Jun 14
| United States v. Roche | 38266 | Unpublished | 16 Jun 14
| United States v. Estacio | 38256 | Unpublished | 11 Jun 14
| United States v. Wade | 38332 | Unpublished | 09 Jun 14
| United States v. Mitchell | 38254 | Unpublished | 05 Jun 14
| United States v. Betts | 38432 | Merits | 27 May 14
| United States v. Rieber | 38226 | Unpublished | 22 May 14
| United States v. Wright | 38448 | Merits | 22 May 14
| United States v. Anderson | 38399 | Unpublished | 19 May 14
| United States v. Kinsley | S32135 | Unpublished | 19 May 14
| United States v. Roberson | 38257 | Unpublished | 19 May 14
| United States v. Smith | S32121 | Unpublished | 19 May 14
| United States v. Pickering | 38248 | Unpublished | 15 May 14
| United States v. Vazquez | 37563 (rem) | Published | 15 May 14
| United States v. Walker | 38237 | Unpublished | 15 May 14
| United States v. Roy | 2014-06 | Order | 13 May 14
| United States v. Kates | 2014-05 | Order | 09 May 14
| United States v. Gierke | 38439 | Merits | 07 May 14
| United States v. Mann | 38444 | Merits | 07 May 14
| United States v. Spradlin | S32177 | Merits | 07 May 14
| United States v. Oliver | 2014-04 (Corrected Copy) | Order | 05 May 14
| United States v. McIntosh | 37977 | Order | 02 May 14
| United States v. Lee | S32066 | Unpublished | 30 Apr 14
| United States v. Lovely | 38215 | Published | 30 Apr 14
| United States v. Taylor | 38247 | Unpublished | 30 Apr 14
| United States v. Burl | 38433 | Merits | 23 Apr 14
| United States v. Sanchez | S32144 | Merits | 23 Apr 14
| United States v. Price | 38045 (rem) | Unpublished | 22 Apr 14
| United States v. Dennis | S32151 (Corrected Copy) |  | 21 Apr 14
| United States v. Nettles | 38336 (Corrected Copy) | Unpublished | 21 Apr 14
| United States v. Hall | 38241 | Published | 11 Apr 14
| United States v. Katso | 38005 | Published | 11 Apr 14
| United States v. Purdy | 2014-03 | Order | 11 Apr 14
| United States v. Schenck | S32158 | Merits | 11 Apr 14
| United States v. Mandy | 38227 | Published | 10 Apr 14
| United States v. Buford | 2013-26 | Article 62 | 04 Apr 14
| United States v. Hudgins | 38305 (Corrected Copy) | Unpublished | 03 Apr 14
| United States v. Daniel | 38322 | Unpublished | 01 Apr 14
| United States v. Shaffer | S32140 | Merits | 01 Apr 14
| United States v. Washington | 2013-29 | Order | 01 Apr 14
| United States v. Bookman | 38342 | Unpublished | 31 Mar 14
| United States v. Allen | 38159 | Unpublished | 28 Mar 14
| United States v. Lynch | 38094 (rem) | Unpublished | 28 Mar 14
| United States v. Palmaccio | 38326 | Merits | 28 Mar 14
| United States v. Ryan | S32150 | Unpublished | 28 Mar 14
| United States v. Evans | S32154 | Merits | 20 Mar 14
| United States v. Hohenstein | 37965 (rem) | Unpublished | 20 Mar 14
| United States v. Jackson | 38244 | Unpublished | 19 Mar 14
| United States v. Olson | S32034 | Unpublished | 18 Mar 14
| United States v. Pyffer | 38411 |  | 18 Mar 14
| United States v. Lightner | 38253 | Unpublished | 14 Mar 14
| United States v. Barlow | 37981 | Unpublished | 13 Mar 14
| United States v. Brooks | 38245 | Unpublished | 13 Mar 14
| United States v. Cherubini | 38292 | Unpublished | 13 Mar 14
| United States v. DeMario | 2013-28 | Order | 13 Mar 14
| United States v. Arness | 2013-30 | Order | 11 Mar 14
| United States v. Bryant | 38405 | Merits | 11 Mar 14
| United States v. Eyster | S32166 | Merits | 11 Mar 14
| United States v. Grottenthaler | 38380 | Unpublished | 11 Mar 14
| United States v. Milano | S32122 | Unpublished | 11 Mar 14
| United States v. Lammens | 38185 | Unpublished | 07 Mar 14
| United States v. Garrison | 38093 (rem) | Unpublished | 05 Mar 14
| United States v. Miller | 38327 | Unpublished | 05 Mar 14
| United States v. Rodriguez | 38080 (rem) | Unpublished | 05 Mar 14
| United States v. Lyle | S32147 | Merits | 27 Feb 14
| United States v. Chapman | 2013-31 | Order | 25 Feb 14
| United States v. Chappell | S32027 (rem) | Unpublished | 25 Feb 14
| United States v. Dennis | S32115 | Unpublished | 25 Feb 14
| United States v. Gutierrez | 37913 (rem) | Unpublished | 25 Feb 14
| United States v. Wagner | S32076 (Corrected Copy) | Unpublished | 25 Feb 14
| United States v. Jordan | 38319 | Unpublished | 24 Feb 14
| United States v. Lambert | 38291 | Unpublished | 24 Feb 14
| United States v. Miller | 38211 | Unpublished | 24 Feb 14
| United States v. Seton | 2013-27 | Article 62 | 24 Feb 14
| United States v. Williams | 38394 | Merits | 24 Feb 14
| United States v. Zare | 38374 | Merits | 24 Feb 14
| United States v. Yarber | 2013-25 | Article 62 | 20 Feb 14
| United States v. Basabe | 38277 | Unpublished | 19 Feb 14
| United States v. Leps | S32129 | Unpublished | 19 Feb 14
| United States v. Sigo | 38268 | Unpublished | 19 Feb 14
| United States v. Rose | 36508 (rem) | Unpublished | 18 Feb 14
| United States v. Flores | 38382 | Merits | 12 Feb 14
| United States v. Lindgren | 38299 | Unpublished | 12 Feb 14
| United States v. Pope | S32132 | Merits | 12 Feb 14
| United States v. Ramseur | S32159 | Merits | 12 Feb 14
| United States v. Rozell | 38381 | Merits | 12 Feb 14
| United States v. Dickinson | S32134 | Unpublished | 10 Feb 14
| United States v. Gurney | 37905 (recon) | Published | 10 Feb 14
| United States v. LaSalle | 38323 | Unpublished | 10 Feb 14
| United States v. Biehunko | S32117 | Unpublished | 06 Feb 14
| United States v. Stewart | 38320 | Merits | 06 Feb 14
| United States v. Jagassar | 38228 | Unpublished | 04 Feb 14
| United States v. Wilson | 37897 (rem) | Published | 30 Jan 14
| United States v. Thompson | S32019 (rem) | Unpublished | 29 Jan 14
| United States v. McIntosh | 37977 | Unpublished | 17 Jan 14
| United States v. Miller | 37869 | Unpublished | 17 Jan 14
| United States v. Hightower | 38354 | Merits | 16 Jan 14
| United States v. McIntyre | 2013-24 | Article 62 | 16 Jan 14
| United States v. Newsom | 38224 | Unpublished | 16 Jan 14
| United States v. LaFollette | 38174 | Unpublished | 14 Jan 14
| United States v. Morita | 37838 | Published | 10 Jan 14
| United States v. Kennedy | 38358 | Merits | 09 Jan 14
AFCCA opinions are published in Adobe Acrobat Portable Document Format (*.PDF) to increase the quality of documents as well as present them in what is a widely accepted format. To view the cases, Adobe Acrobat Reader is required and may be download free of charge.
Download Free Viewers: Adobe PDF

| 2004 AF Judge Advocate General's Corps Privacy and Security Notice | Contact Webmaster